CudaDeviceBuffer

Struct CudaDeviceBuffer 

pub struct CudaDeviceBuffer { /* private fields */ }
Owned CUDA device buffer.

Implementations

Source

impl CudaDeviceBuffer

pub fn context(&self) -> CudaContext

CUDA context that owns this allocation.

pub fn device_ptr(&self) -> u64

Raw CUDA device pointer value.

pub fn byte_len(&self) -> usize

Device allocation length in bytes.

pub fn copy_to_host(&self, out: &mut [u8]) -> Result<(), CudaError>

Copy device bytes into caller-owned host output.

pub fn copy_range_to_host( &self, offset: usize, out: &mut [u8], ) -> Result<(), CudaError>

Copy a byte range from this device buffer into caller-owned host output.

pub fn copy_range_to_host_uninit( &self, offset: usize, out: &mut [MaybeUninit<u8>], ) -> Result<(), CudaError>

Copy a byte range from this device buffer into uninitialized host output.