#[non_exhaustive]pub enum CudaError {
Show 14 variants
Unavailable {
message: String,
},
Driver {
operation: &'static str,
code: c_int,
name: String,
},
OutputTooSmall {
required: usize,
have: usize,
},
LengthTooLarge {
len: usize,
},
HostAllocationFailed {
bytes: usize,
},
HostAllocationTooLarge {
requested: usize,
cap: usize,
what: &'static str,
},
LengthNotElementAligned {
bytes: usize,
element_size: usize,
},
ImageTooLarge {
width: u32,
height: u32,
channels: usize,
},
StatePoisoned {
message: String,
},
CompletionFailed {
primary: Box<CudaError>,
completion: Box<CudaError>,
},
ResourceReleaseFailed {
primary: Box<CudaError>,
release: Box<CudaError>,
},
KernelStatus {
kernel: &'static str,
code: u32,
detail: u32,
},
InvalidArgument {
message: String,
},
InternalInvariant {
what: &'static str,
},
}Expand description
Error returned by CUDA driver and J2K CUDA kernel helpers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CUDA driver library or device is unavailable.
Driver
CUDA Driver API call failed.
Fields
OutputTooSmall
Host output buffer is too small for a device download.
LengthTooLarge
Byte length cannot be represented by the kernel ABI.
HostAllocationFailed
A host-side allocation needed by a CUDA operation could not be reserved.
HostAllocationTooLarge
Simultaneously live host allocations would exceed the codec policy.
Fields
LengthNotElementAligned
Device byte length is not aligned to the requested typed view element.
ImageTooLarge
Image dimensions overflowed allocation or launch geometry.
StatePoisoned
Internal runtime state lock was poisoned.
CompletionFailed
A CUDA operation failed and the follow-up completion check also failed.
Fields
ResourceReleaseFailed
A CUDA operation failed and releasing its retained resources also failed.
Fields
KernelStatus
A J2K CUDA kernel reported a validated runtime failure.
Fields
InvalidArgument
Caller supplied arguments that cannot be represented by this runtime API.
InternalInvariant
Validated host-side planning state contradicted materialized launch data.
Implementations